@@ -7,8 +7,8 @@ import time
 import mxnet as mx
 import numpy as np
 from mxnet import ndarray as nd
-sys.path.append("../")
-from utils.tools import download_url
+
+from face_recognition.utils.tools import download_url
 
 try:
     from rcnn.processing.bbox_transform import clip_boxes
